@@ -28,8 +28,7 @@
 
 #include <gtk/gtkmessagedialog.h>
 #include <gtk/gtkhbox.h>
-#include <gtk/gtkicontheme.h>
-#include <libgnomeui/libgnomeui.h>
+#include <libgnomeui/gnome-help.h>
 
 #include <bonobo/bonobo-shlib-factory.h>
 
@@ -104,8 +103,6 @@ about_cb (BonoboUIComponent *uic,
           SystemTray        *tray,
           const gchar       *verbname)
 {
-  GdkPixbuf    *pixbuf;
-  GtkIconTheme *icon_theme;
   GdkScreen    *screen;
 
   const char *authors[] = {
@@ -117,7 +114,7 @@ about_cb (BonoboUIComponent *uic,
     "Sun GNOME Documentation Team <gdocteam@sun.com>",
     NULL
   };
-  const char *translator_credits = _("translator_credits");
+  const char *translator_credits = _("translator-credits");
 
   screen = gtk_widget_get_screen (GTK_WIDGET (tray->applet));
 
@@ -128,24 +125,17 @@ about_cb (BonoboUIComponent *uic,
       return;
     }
 
-  icon_theme = gtk_icon_theme_get_for_screen (screen);
-  pixbuf = gtk_icon_theme_load_icon (icon_theme,
-				     "panel-notification-area",
-                                     48,
-				     0,
-				     NULL);
-
-  tray->about_dialog = gnome_about_new (_("Panel Notification Area"), VERSION,
-					"Copyright \xc2\xa9 2002 Red Hat, Inc.",
-					NULL,
-					(const char **) authors,
-					(const char **) documenters,
-					strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-					pixbuf);
+  tray->about_dialog = gtk_about_dialog_new ();
+  g_object_set (tray->about_dialog,
+                "name", _("Panel Notification Area"),
+                "version", VERSION,
+                "copyright", "Copyright \xc2\xa9 2002 Red Hat, Inc.",
+                "authors", (const char **) authors,
+                "documenters", (const char **) documenters,
+                "translator_credits", strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
+                "logo_icon_name", "panel-notification-area",
+                NULL);
   
-  if (pixbuf)
-    g_object_unref (pixbuf);
-
   gtk_window_set_screen (GTK_WINDOW (tray->about_dialog), screen);
 
   g_object_add_weak_pointer (G_OBJECT (tray->about_dialog),
@@ -203,8 +193,7 @@ message_cancelled (EggTrayManager *manager, GtkWidget *icon, glong id,
 static void
 update_size_and_orientation (SystemTray *tray)
 {
-  gtk_obox_set_orientation (GTK_OBOX (tray->box),
-                            tray->orientation);
+  tray_obox_set_orientation (TRAY_OBOX (tray->box), tray->orientation);
 
   /* note, you want this larger if the frame has non-NONE relief by default. */
 #define MIN_BOX_SIZE 3
@@ -257,26 +246,34 @@ static void
 applet_change_background (PanelApplet               *applet,
 			  PanelAppletBackgroundType  type,
 			  GdkColor                  *color,
-			  const gchar               *pixmap,
+			  GdkPixmap                 *pixmap,
 			  SystemTray                *tray)
 {
-  if (type == PANEL_NO_BACKGROUND)
-    {
-      GtkRcStyle *rc_style = gtk_rc_style_new ();
-      
-      gtk_widget_modify_style (GTK_WIDGET (tray->applet), rc_style);
+  GtkRcStyle *rc_style;
+  GtkStyle   *style;
 
-      g_object_unref (G_OBJECT (rc_style));
-    }
-  else if (type == PANEL_COLOR_BACKGROUND)
+  /* reset style */
+  gtk_widget_set_style (GTK_WIDGET (tray->applet), NULL);
+  rc_style = gtk_rc_style_new ();
+  gtk_widget_modify_style (GTK_WIDGET (tray->applet), rc_style);
+  g_object_unref (rc_style);
+
+  switch (type)
     {
+    case PANEL_NO_BACKGROUND:
+      break;
+    case PANEL_COLOR_BACKGROUND:
       gtk_widget_modify_bg (GTK_WIDGET (tray->applet),
-                            GTK_STATE_NORMAL,
-                            color);
-    }
-  else
-    { /* pixmap */
-      /* FIXME: Handle this when the panel support works again */
+                            GTK_STATE_NORMAL, color);
+      break;
+    case PANEL_PIXMAP_BACKGROUND:
+      style = gtk_style_copy (GTK_WIDGET (tray->applet)->style);
+      if (style->bg_pixmap[GTK_STATE_NORMAL])
+        g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
+
+      style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
+      gtk_widget_set_style (GTK_WIDGET (tray->applet), style);
+      break;
     }
 }
 
@@ -361,7 +358,7 @@ applet_factory (PanelApplet *applet,
   atk_object_set_name (atko, _("Panel Notification Area"));
 
   tray->frame = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
-  tray->box = gtk_obox_new ();
+  tray->box = tray_obox_new ();
   gtk_box_set_spacing (GTK_BOX (tray->box), 1);
 
   gtk_container_add (GTK_CONTAINER (tray->frame), tray->box);
@@ -410,6 +407,7 @@ applet_factory (PanelApplet *applet,
   
   gtk_container_add (GTK_CONTAINER (tray->applet), tray->frame);
   
+  gtk_window_set_default_icon_name ("panel-notification-area");
   gtk_widget_show_all (GTK_WIDGET (tray->applet));
   
   panel_applet_setup_menu_from_file (PANEL_APPLET (applet), 
