@@ -23,13 +23,14 @@
 
 #include <config.h>
 #include "showdesktop.h"
+#include <gtk/gtkaboutdialog.h>
 #include <gtk/gtktogglebutton.h>
 #include <gtk/gtktooltips.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkmessagedialog.h>
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
+#include <libgnomeui/gnome-help.h>
+#include <libgnomeui/gnome-icon-theme.h>
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/screen.h>
 #include "wncklet.h"
@@ -123,24 +124,33 @@ static void
 applet_change_background (PanelApplet               *applet,
                           PanelAppletBackgroundType  type,
                           GdkColor                  *color,
-                          const gchar               *pixmap,
-                          ShowDesktopData                 *sdd)
+                          GdkPixmap                 *pixmap,
+                          ShowDesktopData           *sdd)
 {
-        if (type == PANEL_NO_BACKGROUND) {
-                GtkRcStyle *rc_style;
+	GtkRcStyle *rc_style;
+	GtkStyle   *style;
 
-                rc_style = gtk_rc_style_new ();
+	/* reset style */
+	gtk_widget_set_style (GTK_WIDGET (sdd->applet), NULL);
+	rc_style = gtk_rc_style_new ();
+	gtk_widget_modify_style (GTK_WIDGET (sdd->applet), rc_style);
+	g_object_unref (rc_style);
 
-                gtk_widget_modify_style (sdd->applet, rc_style);
-
-                g_object_unref (rc_style);
-
-        } else if (type == PANEL_COLOR_BACKGROUND)
-                gtk_widget_modify_bg (sdd->applet, GTK_STATE_NORMAL, color);
-
-        /* else if (type == PANEL_PIXMAP_BACKGROUND)
-         * FIXME: Handle this when the panel support works again
-         */
+	switch (type) {
+	case PANEL_NO_BACKGROUND:
+		break;
+	case PANEL_COLOR_BACKGROUND:
+		gtk_widget_modify_bg (GTK_WIDGET (sdd->applet),
+				      GTK_STATE_NORMAL, color);
+		break;
+	case PANEL_PIXMAP_BACKGROUND:
+		style = gtk_style_copy (GTK_WIDGET (sdd->applet)->style);
+		if (style->bg_pixmap[GTK_STATE_NORMAL])
+			g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
+		style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
+		gtk_widget_set_style (GTK_WIDGET (sdd->applet), style);
+		break;
+	}
 }
 
 /* this is when the panel size changes */
@@ -453,7 +463,7 @@ display_about_dialog (BonoboUIComponent *uic,
         };
 
         /* Translator credits */
-        const char *translator_credits = _("translator_credits");
+        const char *translator_credits = _("translator-credits");
 
         if (sdd->about_dialog) {
                 gtk_window_set_screen (GTK_WINDOW (sdd->about_dialog),
@@ -462,20 +472,24 @@ display_about_dialog (BonoboUIComponent *uic,
                 return;
         }
 
-        sdd->about_dialog = gnome_about_new (_("Show Desktop Button"), VERSION,
-                                 "Copyright \xc2\xa9 2002 Red Hat, Inc.",
-                                 _("This button lets you hide all windows and show the desktop"),
-                                 authors,
-                                 documenters,
-                                 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-                                 sdd->icon);
+        sdd->about_dialog = gtk_about_dialog_new ();
+        g_object_set (sdd->about_dialog,
+                      "name",  _("Show Desktop Button"),
+                      "version", VERSION,
+                      "copyright", "Copyright \xc2\xa9 2002 Red Hat, Inc.",
+                      "comments", _("This button lets you hide all windows and show the desktop."),
+                      "authors", authors,
+                      "documenters", documenters,
+                      "translator_credits", strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
+                      "logo_icon_name", "gnome-fs-desktop",
+                      NULL);
 
         gtk_window_set_wmclass (GTK_WINDOW (sdd->about_dialog), "show-desktop", "show-desktop");
         gtk_window_set_screen (GTK_WINDOW (sdd->about_dialog),
                                gtk_widget_get_screen (sdd->applet));
 
-        if (sdd->icon)
-                gtk_window_set_icon (GTK_WINDOW (sdd->about_dialog), sdd->icon);
+	gtk_window_set_icon_name (GTK_WINDOW (sdd->about_dialog),
+				  "gnome-fs-desktop"); 
 
         g_signal_connect (G_OBJECT(sdd->about_dialog), "destroy",
                           (GCallback)gtk_widget_destroyed, &sdd->about_dialog);
