@@ -16,7 +16,6 @@
 #include "button-widget.h"
 #include "drawer.h"
 #include "launcher.h"
-#include "menu-util.h"
 #include "menu.h"
 #include "panel-gconf.h"
 #include "panel-config-global.h"
@@ -512,6 +511,48 @@ panel_applet_menu_set_recurse (GtkMenu     *menu,
 	g_list_free (children);
 }
 
+void
+panel_applet_position_menu (GtkMenu   *menu,
+			    int       *x,
+			    int       *y,
+			    gboolean  *push_in,
+			    GtkWidget *applet)
+{
+	GtkRequisition  requisition;
+	GdkScreen      *screen;
+	int             menu_x = 0;
+	int             menu_y = 0;
+
+	g_return_if_fail (PANEL_IS_WIDGET (applet->parent));
+
+	screen = gtk_widget_get_screen (applet);
+
+	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
+
+	gdk_window_get_origin (applet->window, &menu_x, &menu_y);
+
+	if (GTK_WIDGET_NO_WINDOW (applet)) {
+		menu_x += applet->allocation.x;
+		menu_y += applet->allocation.y;
+	}
+
+	if (PANEL_WIDGET (applet->parent)->orient == GTK_ORIENTATION_HORIZONTAL) {
+		if (menu_y > gdk_screen_get_height (screen) / 2)
+			menu_y -= requisition.height;
+		else
+			menu_y += applet->allocation.height;
+	} else {
+		if (menu_x > gdk_screen_get_width (screen) / 2)
+			menu_x -= requisition.width;
+		else
+			menu_x += applet->allocation.width;
+	}
+
+	*x = menu_x;
+	*y = menu_y;
+	*push_in = TRUE;
+}
+
 static void
 applet_show_menu (AppletInfo     *info,
 		  GdkEventButton *event)
@@ -543,7 +584,7 @@ applet_show_menu (AppletInfo     *info,
 	gtk_menu_popup (GTK_MENU (info->menu),
 			NULL,
 			NULL,
-			(GtkMenuPositionFunc) panel_position_applet_menu,
+			(GtkMenuPositionFunc) panel_applet_position_menu,
 			info->widget,
 			event->button,
 			event->time);
@@ -886,7 +927,6 @@ panel_applet_save_position (AppletInfo *applet_info,
 	PanelGConfKeyType  key_type;
 	GConfClient       *client;
 	PanelWidget       *panel_widget;
-	const char        *profile;
 	const char        *key;
 	const char        *toplevel_id;
 	char              *old_toplevel_id;
@@ -914,7 +954,6 @@ panel_applet_save_position (AppletInfo *applet_info,
 		return;
 
 	client  = panel_gconf_get_client ();
-	profile = panel_profile_get_name ();
 
 	key_type = applet_info->type == PANEL_OBJECT_BONOBO ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
 	
@@ -923,7 +962,7 @@ panel_applet_save_position (AppletInfo *applet_info,
 	/* FIXME: Instead of getting keys, comparing and setting, there
 	   should be a dirty flag */
 
-	key = panel_gconf_full_key (key_type, profile, id, "toplevel_id");
+	key = panel_gconf_full_key (key_type, id, "toplevel_id");
 	old_toplevel_id = gconf_client_get_string (client, key, NULL);
 	if (old_toplevel_id == NULL || strcmp (old_toplevel_id, toplevel_id) != 0)
 		gconf_client_set_string (client, key, toplevel_id, NULL);
@@ -936,7 +975,7 @@ panel_applet_save_position (AppletInfo *applet_info,
 
 	right_stick = panel_is_applet_right_stick (applet_info->widget) ? 1 : 0;
 	key = panel_gconf_full_key (
-			key_type, profile, id, "panel_right_stick");
+			key_type, id, "panel_right_stick");
 	if (gconf_client_key_is_writable (client, key, NULL) &&
 	    (gconf_client_get_bool (client, key, NULL) ? 1 : 0) != right_stick)
 		gconf_client_set_bool (client, key, right_stick, NULL);
@@ -945,13 +984,13 @@ panel_applet_save_position (AppletInfo *applet_info,
 	if (right_stick && !panel_widget->packed)
 		position = panel_widget->size - position;
 
-	key = panel_gconf_full_key (key_type, profile, id, "position");
+	key = panel_gconf_full_key (key_type, id, "position");
 	if (gconf_client_key_is_writable (client, key, NULL) &&
 	    gconf_client_get_int (client, key, NULL) != position)
 		gconf_client_set_int (client, key, position, NULL);
 	
 	locked = panel_widget_get_applet_locked (panel_widget, applet_info->widget) ? 1 : 0;
-	key = panel_gconf_full_key (key_type, profile, id, "locked");
+	key = panel_gconf_full_key (key_type, id, "locked");
 	if (gconf_client_get_bool (client, key, NULL) ? 1 : 0 != locked)
 		gconf_client_set_bool (client, key, locked, NULL);
 }
@@ -1141,7 +1180,6 @@ panel_applet_can_freely_move (AppletInfo *applet)
 	PanelWidget       *panel_widget;
 	GConfClient       *client;
 	PanelGConfKeyType  key_type;
-	const char        *profile;
 	const char        *key;
 
 	if (panel_lockdown_get_locked_down ())
@@ -1150,19 +1188,18 @@ panel_applet_can_freely_move (AppletInfo *applet)
 	panel_widget = PANEL_WIDGET (applet->widget->parent);
 
 	client  = panel_gconf_get_client ();
-	profile = panel_profile_get_name ();
 	
 	key_type = (applet->type == PANEL_OBJECT_BONOBO) ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
        
-	key = panel_gconf_full_key (key_type, profile, applet->id, "position");
+	key = panel_gconf_full_key (key_type, applet->id, "position");
 	if (!gconf_client_key_is_writable (client, key, NULL))
 		return FALSE;
 
-	key = panel_gconf_full_key (key_type, profile, applet->id, "toplevel_id");
+	key = panel_gconf_full_key (key_type, applet->id, "toplevel_id");
 	if (!gconf_client_key_is_writable (client, key, NULL))
 		return FALSE;
 
-	key = panel_gconf_full_key (key_type, profile, applet->id, "panel_right_stick");
+	key = panel_gconf_full_key (key_type, applet->id, "panel_right_stick");
 	if (!gconf_client_key_is_writable (client, key, NULL))
 		return FALSE;
 
@@ -1175,7 +1212,6 @@ panel_applet_lockable (AppletInfo *applet)
 	GConfClient        *client;
 	PanelWidget        *panel_widget;
 	PanelGConfKeyType   key_type;
-	const char         *profile;
 	const char         *key;
 
 	if (panel_lockdown_get_locked_down ())
@@ -1184,11 +1220,10 @@ panel_applet_lockable (AppletInfo *applet)
 	panel_widget = PANEL_WIDGET (applet->widget->parent);
 
 	client  = panel_gconf_get_client ();
-	profile = panel_profile_get_name ();
 	
 	key_type = (applet->type == PANEL_OBJECT_BONOBO) ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
 
-	key = panel_gconf_full_key (key_type, profile, applet->id, "locked");
+	key = panel_gconf_full_key (key_type, applet->id, "locked");
 
 	return gconf_client_key_is_writable (client, key, NULL);
 }
