@@ -27,7 +27,7 @@
 #include "panel-menu-bar.h"
 
 #include <string.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include "panel-util.h"
 #include "panel-action-button.h"
@@ -35,15 +35,12 @@
 #include "panel-recent.h"
 #include "applet.h"
 #include "menu.h"
-#include "menu-util.h"
 #include "panel-globals.h"
 #include "panel-profile.h"
 #include "panel-lockdown.h"
 
 #define PANEL_MENU_BAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_MENU_BAR, PanelMenuBarPrivate))
 
-#define MENU_FLAGS (MAIN_MENU_SYSTEM | MAIN_MENU_DISTRIBUTION_SUB)
-
 struct _PanelMenuBarPrivate {
 	AppletInfo            *info;
 	PanelWidget           *panel;
@@ -62,41 +59,33 @@ panel_menu_bar_show_applications_menu (PanelMenuBar *menubar,
 {
 	gtk_menu_set_screen (GTK_MENU (menu),
 			     gtk_widget_get_screen (GTK_WIDGET (menubar)));
-
-	if (!menu_need_reread (menu))
-		return;
-
-	while (GTK_MENU_SHELL (menu)->children)
-		gtk_widget_destroy (GTK_MENU_SHELL (menu)->children->data);
-
-	create_root_menu (menu, menubar->priv->panel, TRUE, MENU_FLAGS, FALSE);
 }
 
 static void
-panel_menu_bar_append_action_item (PanelMenuBar *menubar,
-				   GtkWidget    *menu,
-				   const char   *title,
-				   const char   *stock_id,
-				   const char   *tooltip,
-				   const char   *drag_id,
-				   GCallback     callback)
+panel_menu_bar_append_action_item (PanelMenuBar          *menubar,
+				   PanelActionButtonType  action_type,
+				   GCallback              callback)
 {
 	GtkWidget *item;
 
 	item = gtk_image_menu_item_new ();
 	setup_stock_menu_item (item,
 			       panel_menu_icon_get_size (),
-			       stock_id,
-			       title,
+			       panel_action_get_stock_icon (action_type),
+			       panel_action_get_text (action_type),
 			       TRUE);
 
-	gtk_tooltips_set_tip (panel_tooltips, item, tooltip, NULL);
+	gtk_tooltips_set_tip (panel_tooltips,
+			      item,
+			      panel_action_get_tooltip (action_type),
+			      NULL);
 
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menubar->priv->actions_menu), item);
 	g_signal_connect (item, "activate", callback, NULL);
 	g_signal_connect (G_OBJECT (item), "button_press_event",
 			  G_CALLBACK (menu_dummy_button_press_event), NULL);
-	setup_internal_applet_drag (item, drag_id);
+	setup_internal_applet_drag (item,
+				    panel_action_get_drag_id (action_type));
 }
 
 static void
@@ -131,13 +120,8 @@ panel_menu_bar_append_actions_menu (PanelMenuBar *menubar)
 	}
 
 	if (!panel_lockdown_get_disable_command_line ()) {
-		panel_menu_bar_append_action_item (
-						   menubar,
-						   menubar->priv->actions_menu,
-						   _("Run Application..."),
-						   PANEL_STOCK_RUN,
-						   _("Run an Application by entering a command"),
-						   "ACTION:run:NEW",
+		panel_menu_bar_append_action_item (menubar,
+						   PANEL_ACTION_RUN,
 						   G_CALLBACK (panel_action_run_program));
 
 		item = gtk_separator_menu_item_new ();
@@ -146,30 +130,20 @@ panel_menu_bar_append_actions_menu (PanelMenuBar *menubar)
 	}
 
 	if (panel_is_program_in_path  ("gnome-search-tool"))
-		panel_menu_bar_append_action_item (
-			menubar,
-			menubar->priv->actions_menu,
-			_("Search for Files..."),
-			PANEL_STOCK_SEARCHTOOL,
-			_("Find files, folders, and documents on your computer"),
-			"ACTION:search:NEW",
-			G_CALLBACK (panel_action_search));
+		panel_menu_bar_append_action_item (menubar,
+						   PANEL_ACTION_SEARCH,
+						   G_CALLBACK (panel_action_search));
 
 	panel_recent_append_documents_menu (menubar->priv->actions_menu);
 
-	if (panel_is_program_in_path ("gnome-panel-screenshot")) {
+	if (panel_is_program_in_path ("gnome-screenshot")) {
 		item = gtk_separator_menu_item_new ();
 		gtk_menu_shell_append (GTK_MENU_SHELL (menubar->priv->actions_menu), item);
 		gtk_widget_show (item);
 
-		panel_menu_bar_append_action_item (
-			menubar,
-			menubar->priv->actions_menu,
-			_("Take Screenshot..."),
-			PANEL_STOCK_SCREENSHOT,
-			_("Take a screenshot of your desktop"),
-			"ACTION:screenshot:NEW",
-			G_CALLBACK (panel_action_screenshot));
+		panel_menu_bar_append_action_item (menubar,
+						   PANEL_ACTION_SCREENSHOT,
+						   G_CALLBACK (panel_action_screenshot));
 	}
 
 	enable_log_out = !panel_lockdown_get_disable_log_out ();
@@ -185,22 +159,13 @@ panel_menu_bar_append_actions_menu (PanelMenuBar *menubar)
 	}
 
 	if (enable_lock_screen)
-		panel_menu_bar_append_action_item (
-			menubar,
-			menubar->priv->actions_menu,
-			_("Lock Screen"), 
-			PANEL_STOCK_LOCKSCREEN, 
-			_("Protect your computer from unauthorized use"),
-			"ACTION:lock:NEW",
-			G_CALLBACK (panel_action_lock_screen));
+		panel_menu_bar_append_action_item (menubar,
+						   PANEL_ACTION_LOCK,
+						   G_CALLBACK (panel_action_lock_screen));
 
 	if (enable_log_out) {
 		panel_menu_bar_append_action_item (menubar,
-						   menubar->priv->actions_menu,
-						   _("Log Out"),
-						   PANEL_STOCK_LOGOUT,
-						   _("Log out of GNOME"),
-						   "ACTION:logout:NEW",
+						   PANEL_ACTION_LOGOUT,
 						   G_CALLBACK (panel_action_logout));
 	}
 
@@ -229,8 +194,7 @@ panel_menu_bar_instance_init (PanelMenuBar      *menubar,
 			panel_menu_bar_icon_get_size ());
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 
-	menubar->priv->applications_menu =
-		create_root_menu (NULL, NULL, TRUE, MENU_FLAGS, FALSE);
+	menubar->priv->applications_menu = create_applications_menu ("applications.menu", NULL);
 
 	/* intercept all right button clicks makes sure they don't
 	   go to the object itself */
@@ -278,7 +242,7 @@ panel_menu_bar_parent_set (GtkWidget *widget,
 static void
 panel_menu_bar_class_init (PanelMenuBarClass *klass)
 {
-	GtkWidgetClass *widget_class  = (GtkWidgetClass *) klass;
+	GtkWidgetClass *widget_class = (GtkWidgetClass *) klass;
 
 	parent_class = g_type_class_peek_parent (klass);
 
