@@ -36,9 +36,7 @@
 
 G_BEGIN_DECLS
 
-void        panel_profile_load     (char *profile_name);
-const char *panel_profile_get_name (void);
-
+void panel_profile_load (void);
 
 const char    *panel_profile_get_toplevel_id    (PanelToplevel     *toplevel);
 PanelToplevel *panel_profile_get_toplevel_by_id (const char        *toplevel_id);
