@@ -28,8 +28,7 @@
 
 #include <gtk/gtkstock.h>
 #include <gtk/gtkiconfactory.h>
-#include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-desktop-item.h>
+#include <glib/gi18n.h>
 
 #include "panel-globals.h"
 
@@ -63,31 +62,15 @@ typedef struct {
 static PanelStockIcon stock_icons [] = {
 	{ PANEL_STOCK_RUN,                 "gnome-run" },
 	{ PANEL_STOCK_SEARCHTOOL,          "gnome-searchtool" },
-	{ PANEL_STOCK_SCREENSHOT,          "gnome-screenshot" },
+	{ PANEL_STOCK_SCREENSHOT,          "applets-screenshooter" },
 	{ PANEL_STOCK_LOCKSCREEN,          "gnome-lockscreen" },
 	{ PANEL_STOCK_LOGOUT,              "gnome-logout" },
 	{ PANEL_STOCK_FORCE_QUIT,          "panel-force-quit" },
 	{ PANEL_STOCK_GNOME_LOGO,          "gnome-logo-icon-transparent"},
 	{ PANEL_STOCK_APPLICATIONS,	   "gnome-applications"},
 	{ PANEL_STOCK_MAIN_MENU,           "gnome-main-menu"},
-	{ PANEL_STOCK_DEBIAN,              "gnome-debian"},
-	{ PANEL_STOCK_SUSE,                "gnome-suse"},
-	{ PANEL_STOCK_CDE,                 "cdeappmenu"},
-	{ PANEL_STOCK_ACCESSORIES,         "gnome-util"},
-	{ PANEL_STOCK_AMUSEMENTS,          "gnome-amusements"},
-	{ PANEL_STOCK_MULTIMEDIA,          "gnome-multimedia"},
-	{ PANEL_STOCK_INTERNET,            "gnome-globe"},
-	{ PANEL_STOCK_UTILITY,             "advanced-directory"},
-	{ PANEL_STOCK_CORNER_PANEL,        "gnome-panel-type-corner" },
-	{ PANEL_STOCK_EDGE_PANEL,          "gnome-panel-type-edge" },
-	{ PANEL_STOCK_FLOATING_PANEL,      "gnome-panel-type-floating" },
-	{ PANEL_STOCK_SLIDING_PANEL,       "gnome-panel-type-sliding" },
-	{ PANEL_STOCK_MENU_PANEL,          "gnome-panel-type-menu" },
 	{ PANEL_STOCK_LAUNCHER,            "launcher-program" },
-	{ PANEL_STOCK_ACTION,		   "gnome-other" },
-	{ PANEL_STOCK_DRAWER,              "panel-drawer" },
-	{ PANEL_STOCK_APPLETS,             "gnome-applets" },
-	{ PANEL_STOCK_DESKTOP,             "gnome-ccdesktop" },
+	{ PANEL_STOCK_DRAWER,              "drawer" }
 };
 
 static void
@@ -101,28 +84,8 @@ panel_init_stock_icons (GtkIconFactory *factory)
 
 	for (i = 0; i < G_N_ELEMENTS (stock_icons); i++) {
 		GtkIconSet *set;
-		char       *filename;
 
-		if (!stock_icons [i].icon)
-			continue;
-
-		/* Look up the icon at an arbitrary large size; if we are
-		 * adding at only one size, we want the largest image
-		 * available
-		 */
-		filename = gnome_desktop_item_find_icon (
-				panel_icon_theme, stock_icons [i].icon, 1000, 0);
-		if (!filename) {
-			g_warning (_("Unable to load panel stock icon '%s'\n"), stock_icons [i].icon);
-
-			/* FIXME: does this take into account the theme? */
-			set = gtk_icon_factory_lookup_default (GTK_STOCK_MISSING_IMAGE);
-			gtk_icon_factory_add (factory, stock_icons [i].stock_id, set);
-			continue;
-		}
-
-		gtk_icon_source_set_filename (source, filename);
-		g_free (filename);
+		gtk_icon_source_set_icon_name (source, stock_icons [i].icon);
 
 		set = gtk_icon_set_new ();
 		gtk_icon_set_add_source (set, source);
