@@ -20,7 +20,6 @@
 #include <libbonobo.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 
@@ -30,8 +29,6 @@
 #include "drawer.h"
 #include "button-widget.h"
 #include "launcher.h"
-#include "menu-fentry.h"
-#include "menu-util.h"
 #include "menu.h"
 #include "panel-util.h"
 #include "panel-config-global.h"
@@ -341,8 +338,7 @@ panel_popup_menu (PanelToplevel *toplevel,
 	gtk_menu_set_screen (GTK_MENU (menu),
 			     gtk_window_get_screen (GTK_WINDOW (toplevel)));
 
-	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
-			panel_menu_position, toplevel, button, activate_time);
+	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, button, activate_time);
 
 	return TRUE;
 }
@@ -433,19 +429,39 @@ drop_url (PanelWidget *panel,
 	  int          position,
 	  const char  *url)
 {
-	char *comment;
+	enum {
+		NETSCAPE_URL_URL,
+		NETSCAPE_URL_NAME
+	};
+	char **netscape_url;
+	char  *name;
+	char  *comment;
 
 	g_return_val_if_fail (url != NULL, FALSE);
 
 	if (!panel_profile_id_lists_are_writable ())
 		return FALSE;
 
-	comment = g_strdup_printf (_("Open URL: %s"), url);
+	netscape_url = g_strsplit (url, "\n", 2);
+	if (!netscape_url || string_empty (netscape_url[NETSCAPE_URL_URL])) {
+		g_strfreev (netscape_url);
+		return FALSE;
+	}
+	
+	comment = g_strdup_printf (_("Open URL: %s"),
+				   netscape_url[NETSCAPE_URL_URL]);
 
-	panel_launcher_create_from_info (
-		panel->toplevel, position, FALSE, url, url, comment, "gnome-globe.png");
+	if (string_empty (netscape_url[NETSCAPE_URL_NAME]))
+		name = netscape_url[NETSCAPE_URL_URL];
+	else
+		name = netscape_url[NETSCAPE_URL_NAME];
+
+	panel_launcher_create_from_info (panel->toplevel, position, FALSE,
+					 netscape_url[NETSCAPE_URL_URL],
+					 name, comment, "gnome-globe.png");
 
 	g_free (comment);
+	g_strfreev (netscape_url);
 
 	return TRUE;
 }
@@ -458,88 +474,58 @@ drop_menu (PanelWidget *panel,
 	if (!panel_profile_id_lists_are_writable ())
 		return FALSE;
 
-	panel_menu_button_create (panel->toplevel, position, menu_path,
-				  menu_path != NULL, menu_path);
+	panel_menu_button_create (panel->toplevel,
+				  position,
+				  menu_path,
+				  menu_path != NULL,
+				  NULL);
 
 	return TRUE;
 }
 
 static gboolean
-drop_nautilus_uri (PanelWidget *panel,
-		   int          position,
-		   const char  *uri,
-		   const char  *icon)
+drop_uri (PanelWidget *panel,
+	  int          position,
+	  const char  *uri,
+	  const char  *icon)
 {
-	char *quoted;
-	char *exec;
-	char *base;
+	char  *base;
 
 	if (!panel_profile_id_lists_are_writable ())
 		return FALSE;
 
-	/* Add -- to avoid the possibility of filenames which would
-	 * be interpreted as command line arguments
-	 */
-	quoted = g_shell_quote (uri);
-	exec = g_strdup_printf ("nautilus -- %s", quoted);
-	g_free (quoted);
-
 	base = g_path_get_basename (uri);
 
 	panel_launcher_create_from_info (
-		panel->toplevel, position, TRUE, exec, base, uri, icon);
+		panel->toplevel, position, FALSE, uri, base, uri, icon);
 
-	g_free (exec);
 	g_free (base);
 
 	return TRUE;
 }
 
 static gboolean
-drop_directory (PanelWidget *panel, int pos, const char *dir)
+drop_urilist (PanelWidget *panel,
+	      int          pos,
+	      char        *urilist)
 {
-	char *tmp;
+	char     **uris;
+	gboolean   success;
+	int        i;
 
-	/* not filename, but path, these are uris, not local
-	 * files */
-	tmp = g_build_path ("/", dir, ".directory", NULL);
-	if (panel_uri_exists (tmp)) {
-		g_free (tmp);
-		return drop_menu (panel, pos, dir);
-	}
-	g_free (tmp);
+	uris = g_uri_list_extract_uris (urilist);
 
-	tmp = g_build_path ("/", dir, ".order", NULL);
-	if (panel_uri_exists (tmp)) {
-		g_free (tmp);
-		return drop_menu (panel, pos, dir);
-	}
-	g_free (tmp);
-
-	if (panel_is_program_in_path ("nautilus")) {
-		/* nautilus */
-		return drop_nautilus_uri (panel, pos, dir, "gnome-fs-directory.png");
-	} else {
-		return drop_menu (panel, pos, dir);
-	}
-}
-
-static gboolean
-drop_urilist (PanelWidget *panel, int pos, char *urilist)
-{
-	gboolean success = TRUE;
-	GList *li, *files;
-
-	files = gnome_vfs_uri_list_parse (urilist);
-
-	for (li = files; li; li = li->next) {
-		GnomeVFSURI *vfs_uri = li->data;
-		gchar *uri = gnome_vfs_uri_to_string (vfs_uri, GNOME_VFS_URI_HIDE_NONE);
-		const char *mimetype;
-		char *basename;
-		char *dirname;
-		char *filename;
+	success = TRUE;
+	for (i = 0; uris[i]; i++) {
+		GnomeVFSURI      *vfs_uri;
 		GnomeVFSFileInfo *info;
+		GnomeVFSResult    res;
+		const char       *uri;
+		char             *basename;
+		char             *dirname;
+		char             *filename;
+
+		uri = uris[i];
 
 		if (strncmp (uri, "http:", strlen ("http:")) == 0 ||
 		    strncmp (uri, "https:", strlen ("https:")) == 0 ||
@@ -556,77 +542,70 @@ drop_urilist (PanelWidget *panel, int pos, char *urilist)
 			continue;
 		}
 
-		mimetype = gnome_vfs_mime_type_from_name (uri);
+		if (!(vfs_uri = gnome_vfs_uri_new (uri))) {
+			success = FALSE;
+			continue;
+		}
+
 		basename = gnome_vfs_uri_extract_short_path_name (vfs_uri);
 		dirname = gnome_vfs_uri_extract_dirname (vfs_uri);
+
 		info = gnome_vfs_file_info_new ();
+		res = gnome_vfs_get_file_info_uri (vfs_uri, info,
+						   GNOME_VFS_FILE_INFO_GET_MIME_TYPE |
+						   GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
+		if (res == GNOME_VFS_OK) {
+			if (info->mime_type &&
+			    !strncmp (info->mime_type, "image", sizeof ("image") - 1)) {
+				if (!set_background_image_from_uri (panel->toplevel, uri))
+					success = FALSE;
+			} else if (info->mime_type != NULL &&
+				   (!strcmp (info->mime_type, "application/x-gnome-app-info") ||
+				    !strcmp (info->mime_type, "application/x-desktop") ||
+				    !strcmp (info->mime_type, "application/x-kde-app-info"))) {
+				if (panel_profile_id_lists_are_writable ())
+					panel_launcher_create (panel->toplevel, pos, uri);
+				else
+					success = FALSE;
+			} else if (info->type != GNOME_VFS_FILE_TYPE_DIRECTORY &&
+				   info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS &&
+				   info->permissions & (GNOME_VFS_PERM_USER_EXEC |
+							GNOME_VFS_PERM_GROUP_EXEC |
+							GNOME_VFS_PERM_OTHER_EXEC) &&
+				   (filename = g_filename_from_uri (uri, NULL, NULL))) {
+				if (panel_profile_id_lists_are_writable ())
+					/* executable and local, so add a launcher with it
+					 */
+					ask_about_launcher (filename, panel, pos, TRUE);
+				else
+					success = FALSE;
+				g_free (filename);
+			} else {
+				const char *icon;
 
-		if (gnome_vfs_get_file_info_uri (vfs_uri, info,
-						 GNOME_VFS_FILE_INFO_DEFAULT) != GNOME_VFS_OK) {
-			gnome_vfs_file_info_unref (info);
-			info = NULL;
-		}
+				icon = NULL;
+				if (info->mime_type)
+					icon = gnome_vfs_mime_get_icon (info->mime_type);
+				if (!icon)
+					icon = "gnome-unknown.png";
 
-		if (mimetype &&
-		    !strncmp (mimetype, "image", sizeof ("image") - 1)) {
-			if ( ! set_background_image_from_uri (panel->toplevel, uri))
-				success = FALSE;
-		} else if (basename != NULL &&
-			   strcmp (basename, ".directory") == 0 &&
-			   dirname != NULL) {
-			/* This is definately a menu */
-			char *menu_uri = g_strconcat (vfs_uri->method_string, ":",
-						      dirname, NULL);
-			if ( ! drop_menu (panel, pos, menu_uri))
-				success = FALSE;
-			g_free (menu_uri);
-		} else if (mimetype != NULL &&
-			   (strcmp(mimetype, "application/x-gnome-app-info") == 0 ||
-			    strcmp(mimetype, "application/x-desktop") == 0 ||
-			    strcmp(mimetype, "application/x-kde-app-info") == 0)) {
-			if (panel_profile_id_lists_are_writable ())
-				panel_launcher_create (panel->toplevel, pos, uri);
-			else
-				success = FALSE;
-		} else if (info != NULL &&
-			   info->type == GNOME_VFS_FILE_TYPE_DIRECTORY) {
-			if ( ! drop_directory (panel, pos, uri))
-				success = FALSE;
-		} else if (info != NULL &&
-			   info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS &&
-			   info->permissions &
-			     (GNOME_VFS_PERM_USER_EXEC |
-			      GNOME_VFS_PERM_GROUP_EXEC |
-			      GNOME_VFS_PERM_OTHER_EXEC) &&
-			   (filename = g_filename_from_uri (uri, NULL, NULL)) != NULL) {
-			if (panel_profile_id_lists_are_writable ())
-				/* executable and local, so add a launcher with
-				 * it */
-				ask_about_launcher (filename, panel, pos, TRUE);
-			else
-				success = FALSE;
-			g_free (filename);
+				if (!drop_uri (panel, pos, uri, icon))
+					success = FALSE;
+			}
 		} else {
-			/* FIXME: add a launcher that will launch the app
-			 * associated with this file */
-			/* FIXME: For now just add a launcher that launches
-			 * nautilus on this uri */
-			const char *icon = NULL;
-			if (mimetype != NULL)
-		        	icon = gnome_vfs_mime_get_icon (mimetype);
-			if (icon == NULL)
-				icon = "gnome-unknown.png";
-			if ( ! drop_nautilus_uri (panel, pos, uri, icon))
+			if (!drop_uri (panel, pos, uri, "gnome-unknown.png"))
 				success = FALSE;
 		}
-		if (info != NULL)
-			gnome_vfs_file_info_unref (info);
+
+		gnome_vfs_file_info_unref (info);
+
 		g_free (basename);
 		g_free (dirname);
-		g_free (uri);
+
+		gnome_vfs_uri_unref (vfs_uri);
 	}
 
-	gnome_vfs_uri_list_free (files);
+	g_strfreev (uris);
 
 	return success;
 }
@@ -999,7 +978,7 @@ panel_receive_dnd_data (PanelWidget      *panel,
 		}
 		break;
 	case TARGET_DIRECTORY:
-		success = drop_directory (panel, pos, (char *)selection_data->data);
+		success = drop_uri (panel, pos, (char *)selection_data->data, "gnome-fs-directory.png");
 		break;
 	case TARGET_APPLET:
 		if (!selection_data->data) {
@@ -1259,6 +1238,7 @@ panel_deletion_dialog (PanelToplevel *toplevel)
                            toplevel);
 
 	g_object_set_data (G_OBJECT (toplevel), "panel-delete-dialog", dialog);
+	panel_toplevel_push_autohide_disabler (toplevel);
 
 	return dialog;
 }
